@@ -1,4 +1,4 @@
-// shinyjs 0.1.4 by Dean Attal
+// shinyjs 0.2.3 by Dean Attal
 // Perform common JavaScript operations in Shiny apps using plain R code
 
 shinyjs = function() {
@@ -68,8 +68,8 @@ shinyjs = function() {
       $els = $(params.selector);
     }
     if ($els === null || $els === undefined || $els.length == 0) {
-      console.log("shinyjs: Could not find DOM element using these parameters:");
-      console.log(params);
+      shinyjs.debugMessage("shinyjs: Could not find DOM element using these parameters:");
+      shinyjs.debugMessage(params);
       $els = null;
     }
     return $els;
@@ -109,6 +109,8 @@ shinyjs = function() {
   };
 
   var _initDisabledHelper = function(els) {
+    if (els.length == 0) return;
+
     // use a tiny delay because some input elements (sliders, selectize) need
     // to first be initialized, and I don't know how to tell when they're ready
     setTimeout(function() {
@@ -445,6 +447,17 @@ shinyjs = function() {
 
   return {
 
+    // by default, debug mode is off. If shinyjs is initialized with debug mode,
+    // then debugging messages will be printed to the console
+    debug : false,
+
+    // write a message to the console for debugging purposes if debug mode is on
+    debugMessage : function(text) {
+      if (shinyjs.debug) {
+        console.log(text);
+      }
+    },
+
     // Given a set of user-provided parameters and some default parameters,
     // return a dictionary of key-value parameter pairs.
     // The user parameters can either be an (unnamed) array, in which case
